@@ -642,7 +642,7 @@ eel_gdk_window_focus (GdkWindow *window, guint32 timestamp)
 	gdk_error_trap_push ();
 	XSetInputFocus (GDK_DISPLAY (),
 			GDK_WINDOW_XWINDOW (window),
-			RevertToNone,
+			RevertToPointerRoot,
 			timestamp);
 	gdk_flush();
 	gdk_error_trap_pop ();
