@@ -28,15 +28,11 @@
 #include <eel/eel-art-extensions.h>
 #include <eel/eel-art-gtk-extensions.h>
 #include <eel/eel-background.h>
-#include <eel/eel-caption-table.h>
 #include <eel/eel-caption.h>
-#include <eel/eel-clist.h>
-#include <eel/eel-ctree.h>
 #include <eel/eel-dateedit-extensions.h>
 #include <eel/eel-ellipsizing-label.h>
 #include <eel/eel-enumeration.h>
 #include <eel/eel-features.h>
-#include <eel/eel-font-picker.h>
 #include <eel/eel-gconf-extensions.h>
 #include <eel/eel-gdk-extensions.h>
 #include <eel/eel-gdk-pixbuf-extensions.h>
@@ -50,23 +46,14 @@
 #include <eel/eel-image-chooser.h>
 #include <eel/eel-image-table.h>
 #include <eel/eel-labeled-image.h>
-#include <eel/eel-list-column-title.h>
-#include <eel/eel-list.h>
 #include <eel/eel-pango-extensions.h>
-#include <eel/eel-password-dialog.h>
-#include <eel/eel-preferences-box.h>
-#include <eel/eel-preferences-group.h>
-#include <eel/eel-preferences-item.h>
-#include <eel/eel-preferences-pane.h>
 #include <eel/eel-preferences.h>
 #include <eel/eel-radio-button-group.h>
-#include <eel/eel-region.h>
 #include <eel/eel-self-checks.h>
 #include <eel/eel-stock-dialogs.h>
 #include <eel/eel-string-list.h>
 #include <eel/eel-string-picker.h>
 #include <eel/eel-string.h>
-#include <eel/eel-text-caption.h>
 #include <eel/eel-types.h>
 #include <eel/eel-vfs-extensions.h>
 #include <eel/eel-wrap-table.h>
